# Openregister

[![Package](https://img.shields.io/pypi/v/openregister.svg)](https://pypi.python.org/pypi/openregister/)
[![Build](https://travis-ci.org/psd/openregister.svg?branch=master)](https://travis-ci.org/psd/openregister)
[![Coverage](https://coveralls.io/repos/github/psd/openregister/badge.svg?branch=master)](https://coveralls.io/github/psd/openregister?branch=master)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/psd/openregister/blob/master/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://black.readthedocs.io/en/stable/)


*Publishing tools for GOV.UK style registers.*

A self-contained and easily installed [GOV.UK register product](https://www.gov.uk/government/publications/registers/registers) intended for use by devolved authorities and administrations.

## Installation

    $ pip3 install openregister

## Dependencies

Requires Python 3.6 or later, we recommend using a [virtual environment](https://docs.python.org/3/library/venv.html):

    $ make init
    $ make
